@@ -30,6 +30,8 @@
 #include <IOKit/avc/IOFireWireAVCUnit.h>
 #include <IOKit/avc/IOFireWireAVCUserClientCommon.h>
 
+class IOFireWireAVCUserClient;
+
 // A little class to put into the connections set
 class IOFireWireAVCConnection : public OSObject
 {
@@ -41,6 +43,18 @@ public:
 	UInt32 fChannel;
 };
 
+// A wrapper class for async AVC commands created by this user client
+class IOFireWireAVCUserClientAsyncCommand : public OSObject
+{
+    OSDeclareDefaultStructors(IOFireWireAVCUserClientAsyncCommand)
+public:
+	IOFireWireAVCAsynchronousCommand *pAsyncCommand;
+	IOMemoryDescriptor *fMem;
+	IOFireWireAVCUserClient *pUserClient;
+	UInt32 commandIdentifierHandle;
+};
+
+
 class IOFireWireAVCUserClient : public IOUserClient
 {
     OSDeclareDefaultStructors(IOFireWireAVCUserClient)
@@ -48,7 +62,7 @@ class IOFireWireAVCUserClient : public IOUserClient
 protected:
 
     static IOExternalMethod 		sMethods[kIOFWAVCUserClientNumCommands];
-    //static IOExternalAsyncMethod 	sAsyncMethods[kIOFWSBP2UserClientNumAsyncCommands];
+    static IOExternalAsyncMethod 	sAsyncMethods[kIOFWAVCUserClientNumAsyncCommands];
 
     bool					fOpened;
 	bool					fStarted;
@@ -56,6 +70,16 @@ protected:
 	
     IOFireWireAVCNub *		fUnit;
 	OSArray *				fConnections;
+
+	IOLock *				fAsyncAVCCmdLock;
+	OSArray *				fUCAsyncCommands;
+	UInt32					fNextAVCAsyncCommandHandle;
+    OSAsyncReference		fAsyncAVCCmdCallbackInfo;
+	
+#ifdef kUseAsyncAVCCommandForBlockingAVCCommand
+	IOLock *avcCmdLock;
+	IOFireWireAVCAsynchronousCommand *pCommandObject;
+#endif
     
     static void remakeConnections(void *arg);
     virtual IOExternalMethod * getTargetAndMethodForIndex(IOService **target, UInt32 index);
@@ -63,13 +87,11 @@ protected:
     virtual IOReturn IOFireWireAVCUserClient::updateP2PCount(UInt32 addr, SInt32 inc, bool failOnBusReset, UInt32 chan, IOFWSpeed speed);
     virtual IOReturn makeConnection(UInt32 addr, UInt32 chan, IOFWSpeed speed);
     virtual void breakConnection(UInt32 addr);
+	virtual IOFireWireAVCUserClientAsyncCommand *FindUCAsyncCommandWithHandle(UInt32 commandHandle);
     
 public:
-
-    static IOFireWireAVCUserClient* withTask( task_t owningTask );
-
-    virtual bool init( OSDictionary * dictionary = 0 );
-    virtual void free();
+	virtual bool initWithTask(task_t owningTask, void * securityToken, UInt32 type,OSDictionary * properties);
+	virtual void free();
     virtual bool start( IOService * provider );
     virtual void stop( IOService * provider );
 
@@ -92,6 +114,15 @@ public:
     virtual IOReturn breakP2PInputConnection( UInt32 plugNo, void * = 0, void * = 0, void * = 0, void * = 0, void * = 0);
     virtual IOReturn makeP2POutputConnection( UInt32 plugNo, UInt32 chan, IOFWSpeed speed, void * = 0, void * = 0, void * = 0);
     virtual IOReturn breakP2POutputConnection( UInt32 plugNo, void * = 0, void * = 0, void * = 0, void * = 0, void * = 0);
+	
+    virtual IOReturn installUserLibAsyncAVCCommandCallback(OSAsyncReference asyncRef, void *userRefcon, UInt32 *returnParam);
+	
+	virtual IOReturn CreateAVCAsyncCommand(UInt8 * cmd, UInt8 * asyncAVCCommandHandle, UInt32 len, UInt32 *refSize);
+	virtual IOReturn SubmitAVCAsyncCommand(UInt32 commandHandle);
+	virtual IOReturn CancelAVCAsyncCommand(UInt32 commandHandle);
+	virtual IOReturn ReleaseAVCAsyncCommand(UInt32 commandHandle);
+	virtual void HandleUCAsyncCommandCallback(IOFireWireAVCUserClientAsyncCommand *pUCAsyncCommand);
+	virtual IOReturn ReinitAVCAsyncCommand(UInt32 commandHandle, const UInt8 *pCommandBytes, UInt32 len);
 };
 
 #endif // _IOKIT_IOFIREWIREAVCUSERCLIENT_H
\ No newline at end of file
